#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

namespace NinjaTrader.NinjaScript.Indicators.TraderFox {

	public class DownCounter : Indicator {
		
		private int LH = 0;
		private int LL = 0;
		
		NinjaTrader.Gui.Tools.SimpleFont myFont = new NinjaTrader.Gui.Tools.SimpleFont("Courier New", 12) { Size = 12, Bold = true };
		
		protected override void OnStateChange() {
			
			if ( State == State.SetDefaults ) {
				Description = "";
				Name = "TF-DownCounter";
				
				AddPlot( Brushes.Black, "LowerHigh" );
				AddPlot( Brushes.Red, "LowerLow" );
			}
		}

		protected override void OnBarUpdate() {
			
			if ( CurrentBar == 0 ) {
				Values[0][0] = 0;
				Values[1][0] = 0;
				return;
			}
			
			if ( Time[0].Date != Time[1].Date ) {
				LH = 0;
				LL = 0;

				Values[0][0] = 0;
				Values[1][0] = 0;
			}
			
			if ( High[0] < High[1] ) {
				LH++;
			} else if ( High[0] == High[1] ) {
			} else if ( LH > 0 ) {
				LH--;
			}

			if ( Low[0] < Low[1] ) {
				LL++;
			} else if ( Low[0] == Low[1] ) {
			} else if ( LL > 0 ) {
				LL--;
			}
					
			if ( LH > 0 ) {
				Draw.Text( this, "LowerHigh " + CurrentBar, false, LH.ToString(), 0, High[0], 6, Brushes.Black, myFont, TextAlignment.Center, Brushes.Transparent, Brushes.Transparent, 0 );
			}
				
			if ( LL > 0 ) {
				Draw.Text( this, "LowerLow " + CurrentBar, false, LL.ToString(), 0, Low[0], -8, Brushes.Red, myFont, TextAlignment.Center, Brushes.Transparent, Brushes.Transparent, 0 );
			}
			
			Values[0][0] = LH;
			Values[1][0] = LL;

		}
		
		#region Properties
		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> LowerHigh {
			get { return Values[0]; }
		}

		[Browsable(false)]
		[XmlIgnore()]
		public Series<double> LowerLow {
			get { return Values[1]; }
		}
		#endregion

	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private TraderFox.DownCounter[] cacheDownCounter;
		public TraderFox.DownCounter DownCounter()
		{
			return DownCounter(Input);
		}

		public TraderFox.DownCounter DownCounter(ISeries<double> input)
		{
			if (cacheDownCounter != null)
				for (int idx = 0; idx < cacheDownCounter.Length; idx++)
					if (cacheDownCounter[idx] != null &&  cacheDownCounter[idx].EqualsInput(input))
						return cacheDownCounter[idx];
			return CacheIndicator<TraderFox.DownCounter>(new TraderFox.DownCounter(), input, ref cacheDownCounter);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.TraderFox.DownCounter DownCounter()
		{
			return indicator.DownCounter(Input);
		}

		public Indicators.TraderFox.DownCounter DownCounter(ISeries<double> input )
		{
			return indicator.DownCounter(input);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.TraderFox.DownCounter DownCounter()
		{
			return indicator.DownCounter(Input);
		}

		public Indicators.TraderFox.DownCounter DownCounter(ISeries<double> input )
		{
			return indicator.DownCounter(input);
		}
	}
}

#endregion
