#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.Indicators;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Strategies in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Strategies.NeoMarkttechnik.Bots
{
	public class SuperBot : Strategy
	{
		private NinjaTrader.NinjaScript.Indicators.TraderFox.DownCounter DC;
		private NinjaTrader.NinjaScript.Indicators.TraderFox.RangeCounter2 RC;

		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"";
				Name										= "Super Bot";
				Calculate									= Calculate.OnBarClose;
				EntriesPerDirection							= 1;
				EntryHandling								= EntryHandling.AllEntries;
				IsExitOnSessionCloseStrategy				= true;
				ExitOnSessionCloseSeconds					= 30;
				IsFillLimitOnTouch							= false;
				MaximumBarsLookBack							= MaximumBarsLookBack.TwoHundredFiftySix;
				OrderFillResolution							= OrderFillResolution.Standard;
				Slippage									= 0;
				StartBehavior								= StartBehavior.WaitUntilFlat;
				TimeInForce									= TimeInForce.Gtc;
				TraceOrders									= false;
				RealtimeErrorHandling						= RealtimeErrorHandling.StopCancelClose;
				StopTargetHandling							= StopTargetHandling.PerEntryExecution;
				BarsRequiredToTrade							= 20;
				IncludeCommission                           = true;
				// Disable this property for performance gains in Strategy Analyzer optimizations
				// See the Help Guide for additional information
				IsInstantiatedOnEachOptimizationIteration	= true;
				
				Use_Simple_Rebound_Bot = true;
				Use_Tight_Range_Bot = true;
			}
			else if (State == State.Configure) {
			}
			else if (State == State.DataLoaded) {				
				RC = RangeCounter2( Close );
				DC = DownCounter( Close );
			}
		}

		protected override void OnBarUpdate()
		{
			if ( BarsInProgress != 0 ) { return; }
			if ( CurrentBars[0] < 5 ) { return; }
			
			if ( Use_Simple_Rebound_Bot ) {
				Simple_Rebound_Bot();
			}
			
			if ( Use_Tight_Range_Bot ) {
				Tight_Range_Bot();
			}
		}
		
		private void Simple_Rebound_Bot() {
			/* 6 / 1 */
			if ( DC.LowerHigh[0] == 6 && DC.LowerLow[0] == 1 ) {
				if ( Time[0].DayOfWeek == DayOfWeek.Monday || Time[0].DayOfWeek == DayOfWeek.Thursday ) {
					if ( !( Time[0].TimeOfDay >= new TimeSpan(10, 20, 0) && Time[0].TimeOfDay <= new TimeSpan(10, 30, 0) ) ) {
						EnterLong( 1, "" );
						SetProfitTarget("", CalculationMode.Percent, 0.007);
						SetStopLoss("", CalculationMode.Percent, 0.01, false);
					}
				}
			}
			
			/* 6 / 2 */
			if ( DC.LowerHigh[0] == 6 && DC.LowerLow[0] == 2 ) {
				if ( Time[0].DayOfWeek == DayOfWeek.Wednesday || Time[0].DayOfWeek == DayOfWeek.Thursday || Time[0].DayOfWeek == DayOfWeek.Friday ) {
					if ( !( Time[0].TimeOfDay >= new TimeSpan(15, 20, 0) && Time[0].TimeOfDay <= new TimeSpan(16, 10, 0) ) ) {
						if ( !( Time[0].TimeOfDay >= new TimeSpan(19, 20, 0) && Time[0].TimeOfDay <= new TimeSpan(22, 0, 0) ) ) {
							EnterLong( 1, "" );
							SetProfitTarget("", CalculationMode.Percent, 0.01);
							SetStopLoss("", CalculationMode.Percent, 0.006, false);
						}
					}
				}
			}
			
			/* 4 / 5 */
			if ( DC.LowerHigh[0] == 4 && DC.LowerLow[0] == 5 ) {
				if ( Time[0].DayOfWeek == DayOfWeek.Monday || Time[0].DayOfWeek == DayOfWeek.Tuesday || Time[0].DayOfWeek == DayOfWeek.Wednesday || Time[0].DayOfWeek == DayOfWeek.Thursday ) {
					if ( !( Time[0].TimeOfDay >= new TimeSpan(7, 0, 0) && Time[0].TimeOfDay <= new TimeSpan(9, 0, 0) ) ) {
						if ( !( Time[0].TimeOfDay >= new TimeSpan(15, 20, 0) && Time[0].TimeOfDay <= new TimeSpan(16, 10, 0) ) ) {
							EnterLong( 1, "" );
							SetProfitTarget("", CalculationMode.Percent, 0.01);
							SetStopLoss("", CalculationMode.Percent, 0.007, false);
						}
					}
				}
			}

			/* 1 / 3 */
			if ( DC.LowerHigh[0] == 1 && DC.LowerLow[0] == 3 ) {
				if ( Time[0].DayOfWeek == DayOfWeek.Tuesday || Time[0].DayOfWeek == DayOfWeek.Wednesday ) {
					EnterLong( 1, "" );
					SetProfitTarget("", CalculationMode.Percent, 0.01);
					SetStopLoss("", CalculationMode.Percent, 0.009, false);
				}
			}
			
			/* 2 / 4 */
			if ( DC.LowerHigh[0] == 2 && DC.LowerLow[0] == 4 ) {
				if ( Time[0].DayOfWeek == DayOfWeek.Wednesday || Time[0].DayOfWeek == DayOfWeek.Thursday || Time[0].DayOfWeek == DayOfWeek.Friday ) {
					if ( !( Time[0].TimeOfDay >= new TimeSpan(12, 50, 0) && Time[0].TimeOfDay <= new TimeSpan(15, 40, 0) ) ) {
						EnterLong( 1, "" );
						SetProfitTarget("", CalculationMode.Percent, 0.008);
						SetStopLoss("", CalculationMode.Percent, 0.01, false);
					}
				}
			}
		}
		
		private void Tight_Range_Bot() {
			
			if ( Time[0].DayOfWeek != DayOfWeek.Monday && Time[0].DayOfWeek != DayOfWeek.Thursday ) {
				if ( !( Time[0].TimeOfDay >= new TimeSpan( 15, 30, 0 ) && Time[0].TimeOfDay <= new TimeSpan( 15, 40, 0 ) ) ) {
					if ( RC.Range[1] < RC.Range[2] && RC.Range[2] < RC.Range[3] && RC.Range[3] < RC.Range[4] && RC.Range[4] < RC.Range[5] ) {
						EnterLong( 1, "" );
						SetProfitTarget( "", CalculationMode.Percent, 0.007) ;
						SetStopLoss( "", CalculationMode.Percent, 0.004, false );
					}		
				}
			}	
		}

		#region Properties
		
		[NinjaScriptProperty]
		[Display(Name="Simple Rebound", Order=0, GroupName="Bots")]
		public bool Use_Simple_Rebound_Bot
		{ get; set; }

		[NinjaScriptProperty]
		[Display(Name="Tight Range", Order=1, GroupName="Bots")]
		public bool Use_Tight_Range_Bot
		{ get; set; }
		
		#endregion

	}
}
